about summary refs log tree commit diff
path: root/compiler/rustc_driver_impl/src
diff options
context:
space:
mode:
authorbjorn3 <17426603+bjorn3@users.noreply.github.com>2023-11-04 15:59:29 +0000
committerbjorn3 <17426603+bjorn3@users.noreply.github.com>2023-11-26 18:02:47 +0000
commit4acaa0284ef1354f3310d7de0147ea4a371b4389 (patch)
tree522b3cb96683d406c2ec0832b15b093cde055d00 /compiler/rustc_driver_impl/src
parent98a6eaa7f8436cbedc79a21fe3ec62e8a35ef392 (diff)
downloadrust-4acaa0284ef1354f3310d7de0147ea4a371b4389.tar.gz
rust-4acaa0284ef1354f3310d7de0147ea4a371b4389.zip
Feed the output filenames into the TyCtxt
Since the introduction of the crate attribute pre-expansion pass we
don't need access to the TyCtxt to compute it.
Diffstat (limited to 'compiler/rustc_driver_impl/src')
-rw-r--r--compiler/rustc_driver_impl/src/lib.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/compiler/rustc_driver_impl/src/lib.rs b/compiler/rustc_driver_impl/src/lib.rs
index a0794daa23c..7dba0b24637 100644
--- a/compiler/rustc_driver_impl/src/lib.rs
+++ b/compiler/rustc_driver_impl/src/lib.rs
@@ -401,9 +401,9 @@ fn run_compiler(
                         Ok(())
                     })?;
 
                     // Make sure the `output_filenames` query is run for its side
                     // effects of writing the dep-info and reporting errors.
-                    queries.global_ctxt()?.enter(|tcx| tcx.output_filenames(()));
+                    queries.global_ctxt()?.enter(|tcx| tcx.write_dep_info(()));
                 } else {
                     let krate = queries.parse()?;
                     pretty::print(
@@ -431,9 +431,9 @@ fn run_compiler(
                 return early_exit();
             }
 
             // Make sure the `output_filenames` query is run for its side
             // effects of writing the dep-info and reporting errors.
-            queries.global_ctxt()?.enter(|tcx| tcx.output_filenames(()));
+            queries.global_ctxt()?.enter(|tcx| tcx.write_dep_info(()));
 
             if sess.opts.output_types.contains_key(&OutputType::DepInfo)
                 && sess.opts.output_types.len() == 1
@@ -401,9 +401,9 @@ fn run_compiler(
                     })?;
 
-                    // Make sure the `output_filenames` query is run for its side
+                    // Make sure the `write_dep_info` query is run for its side
                     // effects of writing the dep-info and reporting errors.
@@ -431,9 +431,9 @@ fn run_compiler(
             }
 
-            // Make sure the `output_filenames` query is run for its side
+            // Make sure the `write_dep_info` query is run for its side
             // effects of writing the dep-info and reporting errors.